@@ -2,7 +2,7 @@
 
 
 from . import config
-from .htmlhelpers import *
+from .html import *
 from .messages import *
 
 
