@@ -1170,9 +1170,9 @@ def cleanupHTML(doc):
             el.set("data-noexport", "")
 
         if doc.md.slimBuildArtifact:
-            # Remove *all* data- attributes, except data-mdn-for attributes
+            # Remove *all* data- attributes.
             for attrName in el.attrib:
-                if attrName.startswith("data-") and attrName != "data-mdn-for":
+                if attrName.startswith("data-"):
                     removeAttr(el, attrName)
     for el in strayHeadEls:
         head.append(el)
